==> horizon-0.9.3.tar.xz: horizon-0.9.3/image/iso-share/post-ppc64.sh <==
#!/bin/sh

mkdir -p cdroot/boot

# /boot/grub instead of /boot for Petitboot compatibility.
cat >early.cfg <<'EARLYCFG'
search.fs_label "Adelie ppc64" root
set prefix=($root)/boot/grub
EARLYCFG

if ! type grub-mkimage>/dev/null; then
	printf "GRUB image cannot be created.\n"
	exit 1
else
	grub-mkimage -d target/usr/lib/grub/powerpc-ieee1275 -c early.cfg -v -p boot -o cdroot/boot/grubcore.img -O powerpc-ieee1275 boot btrfs datetime disk ext2 gfxmenu help hfs hfsplus ieee1275_fb iso9660 jfs ls luks lvm macbless macho nilfs2 ofnet part_apple part_gpt part_msdos png scsi search xfs linux reboot gfxterm gfxterm_background gfxterm_menu all_video
fi

rm early.cfg

cp cdroot/VolumeIcon.icns 'cdroot/Icon
'

mkdir -p cdroot/boot/grub
cat >cdroot/boot/grub/grub.cfg <<'GRUBCFG'
menuentry "Adelie Linux Live (PowerPC 64-bit)" --class linux --id adelie-live-cd {
        insmod part_apple
        insmod iso9660
        insmod linux
        search --label "Adelie ppc64" --hint cd,apple2 --no-floppy --set
        linux ($root)/kernel-ppc64 squashroot=ppc64.squashfs
        initrd ($root)/initrd-ppc64
}

menuentry "Reboot and Try Again" --class reboot --id reboot {
        reboot
}

GRUB_DEFAULT=adelie-live-cd
GRUB_TIMEOUT=10
GRUB_DISTRIBUTOR="Adelie"
GRUBCFG

cat >cdroot/boot/ofboot.b <<'OFBOOT'
<CHRP-BOOT>
<COMPATIBLE>MacRISC MacRISC3 MacRISC4</COMPATIBLE>
<DESCRIPTION>Adelie</DESCRIPTION>
<OS-NAME>Linux</OS-NAME>
<boot-script>
" screen" output
load-base release-load-area
boot &device;:\boot\grubcore.img
</boot-script>
<OS-BADGE-ICONS>
1010
000000000000F8FEACF6000000000000
0000000000F5FFFFFEFEF50000000000
00000000002BFAFEFAFCF70000000000
0000000000F65D5857812B0000000000
0000000000F5350B2F88560000000000
0000000000F6335708F8FE0000000000
00000000005600F600F5FD8100000000
00000000F9F8000000F5FAFFF8000000
000000008100F5F50000F6FEFE000000
000000F8F700F500F50000FCFFF70000
00000088F70000F50000F5FCFF2B0000
0000002F582A00F5000008ADE02C0000
00090B0A35A62B0000002D3B350A0000
000A0A0B0B3BF60000505E0B0A0B0A00
002E350B0B2F87FAFCF45F0B2E090000
00000007335FF82BF72B575907000000
000000000000ACFFFF81000000000000
000000000081FFFFFFFF810000000000
0000000000FBFFFFFFFFAC0000000000
000000000081DFDFDFFFFB0000000000
000000000081DD5F83FFFD0000000000
000000000081DDDF5EACFF0000000000
0000000000FDF981F981FFFF00000000
00000000FFACF9F9F981FFFFAC000000
00000000FFF98181F9F981FFFF000000
000000ACACF981F981F9F9FFFFAC0000
000000FFACF9F981F9F981FFFFFB0000
00000083DFFBF981F9F95EFFFFFC0000
005F5F5FDDFFFBF9F9F983DDDD5F0000
005F5F5F5FDD81F9F9E7DF5F5F5F5F00
0083DD5F5F83FFFFFFFFDF5F835F0000
000000FBDDDFACFBACFBDFDFFB000000
000000000000FFFFFFFF000000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFF000000
</OS-BADGE-ICONS>
</CHRP-BOOT>
OFBOOT

cp cdroot/boot/ofboot.b cdroot/boot/bootinfo.txt

# CHRP
mkdir -p cdroot/ppc
cp cdroot/boot/bootinfo.txt cdroot/ppc/bootinfo.txt

==> horizon-0.9.9.tar.xz: horizon-0.9.9/image/iso-share/post-ppc64.sh <==
#!/bin/sh

mkdir -p cdroot/boot

# /boot/grub instead of /boot for Petitboot compatibility.
cat >early.cfg <<'EARLYCFG'
search.fs_label "Adelie-ppc64" root
set prefix=($root)/boot/grub
EARLYCFG

if ! type grub-mkimage>/dev/null; then
	printf "GRUB image cannot be created.\n"
	exit 1
else
	grub-mkimage -d target/usr/lib/grub/powerpc-ieee1275 -c early.cfg -v -p boot -o cdroot/boot/grubcore.img -O powerpc-ieee1275 boot btrfs datetime disk ext2 gfxmenu help hfs hfsplus ieee1275_fb iso9660 jfs ls luks lvm macbless macho nilfs2 ofnet part_apple part_gpt part_msdos png scsi search xfs linux reboot gfxterm gfxterm_background gfxterm_menu all_video
fi

rm early.cfg

cp cdroot/VolumeIcon.icns 'cdroot/Icon
'

mkdir -p cdroot/boot/grub
cat >cdroot/boot/grub/grub.cfg <<'GRUBCFG'
menuentry "Adelie Linux Live (PowerPC 64-bit)" --class linux --id adelie-live-cd-ppc64 {
        insmod part_apple
        insmod iso9660
        insmod linux
        search --label "Adelie-ppc64" --hint cd,apple2 --no-floppy --set
        linux /kernel-ppc64 root=live:LABEL=Adelie-ppc64 rd.live.dir=/ rd.live.squashimg=ppc64.squashfs softlevel=graphical
        initrd /initrd-ppc64
}

menuentry "Adelie Linux Live (PowerPC 64-bit) (text-only)" --class linux --id adelie-live-cd-ppc64-text {
        insmod part_apple
        insmod iso9660
        insmod linux
        search --label "Adelie-ppc64" --hint cd,apple2 --no-floppy --set
        linux /kernel-ppc64 root=live:LABEL=Adelie-ppc64 rd.live.dir=/ rd.live.squashimg=ppc64.squashfs
        initrd /initrd-ppc64
}

menuentry "Reboot and Try Again" --class reboot --id reboot {
        reboot
}

GRUB_DEFAULT=adelie-live-cd
GRUB_TIMEOUT=10
GRUB_DISTRIBUTOR="Adelie"
GRUBCFG

cat >cdroot/boot/ofboot.b <<'OFBOOT'
<CHRP-BOOT>
<COMPATIBLE>MacRISC MacRISC3 MacRISC4</COMPATIBLE>
<DESCRIPTION>Adelie</DESCRIPTION>
<OS-NAME>Linux</OS-NAME>
<boot-script>
" screen" output
load-base release-load-area
boot &device;:\boot\grubcore.img
</boot-script>
<OS-BADGE-ICONS>
1010
000000000000F8FEACF6000000000000
0000000000F5FFFFFEFEF50000000000
00000000002BFAFEFAFCF70000000000
0000000000F65D5857812B0000000000
0000000000F5350B2F88560000000000
0000000000F6335708F8FE0000000000
00000000005600F600F5FD8100000000
00000000F9F8000000F5FAFFF8000000
000000008100F5F50000F6FEFE000000
000000F8F700F500F50000FCFFF70000
00000088F70000F50000F5FCFF2B0000
0000002F582A00F5000008ADE02C0000
00090B0A35A62B0000002D3B350A0000
000A0A0B0B3BF60000505E0B0A0B0A00
002E350B0B2F87FAFCF45F0B2E090000
00000007335FF82BF72B575907000000
000000000000ACFFFF81000000000000
000000000081FFFFFFFF810000000000
0000000000FBFFFFFFFFAC0000000000
000000000081DFDFDFFFFB0000000000
000000000081DD5F83FFFD0000000000
000000000081DDDF5EACFF0000000000
0000000000FDF981F981FFFF00000000
00000000FFACF9F9F981FFFFAC000000
00000000FFF98181F9F981FFFF000000
000000ACACF981F981F9F9FFFFAC0000
000000FFACF9F981F9F981FFFFFB0000
00000083DFFBF981F9F95EFFFFFC0000
005F5F5FDDFFFBF9F9F983DDDD5F0000
005F5F5F5FDD81F9F9E7DF5F5F5F5F00
0083DD5F5F83FFFFFFFFDF5F835F0000
000000FBDDDFACFBACFBDFDFFB000000
000000000000FFFFFFFF000000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFFFF00000000
00000000FFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFF000000
</OS-BADGE-ICONS>
</CHRP-BOOT>
OFBOOT

cp cdroot/boot/ofboot.b cdroot/boot/bootinfo.txt

# CHRP
mkdir -p cdroot/ppc/chrp
cp cdroot/boot/bootinfo.txt cdroot/ppc/bootinfo.txt
